Description Usage Arguments Value
Combines samples from the posterior model space of two JAM
models, allowing posterior inference about colocalisation, i.e. about the
existence of one or more shared variants that are associated with both outcome
traits.
1 | cojam(jam_res_1, jam_res_2)
|
jam_res_1 |
A |
jam_res_2 |
A |
A list containing the following elements:
bayes_factorBayes Factor for H4 versus H3.
posterior_overlapPosterior probability of H4 U H3.
model_infoExtra info for other functions / post-processing:
models_gridAll sampled configurations (joint
JAM models) and their posterior counts.
implied_prior_odds_43Prior odds of H4 versus H3 that would
have been implied under an assumption of independence between traits.
Provided as a sanity check for user-supplied priors, which should
usually promote H4 vs H3 (i.e. user supplied prior_odds_43
should usually be greater than implied_prior_odds_43).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.