Convert coloc.abf data to the format required by
JAM, using jam_wrap.
1 | convert_coloc_data(coloc_data, ref_genotypes)
|
coloc_data |
Data formatted for |
ref_genotypes |
Reference genotype matrix used by JAM to impute the SNP-SNP
correlations. Genotypes must be coded as a numeric risk allele
count 0/1/2. Non-integer values reflecting imputation may be given. NB: The
risk allele coding must correspond to that used in |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.